@@ -1,10 +1,10 @@
 #Delay of up to 1 minute returns all markets
 
 GeneralMarketDataAll <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=marketdatav2 ")
+  data <- getURL("https://api.cryptsy.com/api.php?method=marketdatav2 ")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -15,16 +15,18 @@ GeneralMarketDataAll <- function () {
 #' @keywords doge
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_DOGEUSD()
+#' }
 
 
 #DOGECOIN to USD - Realtime
 
 GeneralMarketData_DOGEUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=182")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/182")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -35,15 +37,17 @@ GeneralMarketData_DOGEUSD <- function () {
 #' @keywords bitcoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_BTCUSD()
+#' }
 
 #BITCOIN to USD - Realtime
 
 GeneralMarketData_BTCUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=2")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/2")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -54,15 +58,17 @@ GeneralMarketData_BTCUSD <- function () {
 #' @keywords feathercoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_FTCUSD()
+#' }
 
 #FEATHERCOIN to USD - Realtime
 
 GeneralMarketData_FTCUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=6")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/6")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -73,15 +79,17 @@ GeneralMarketData_FTCUSD <- function () {
 #' @keywords litecoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_LTCUSD()
+#' }
 
 #LITECOIN to USD - Realtime
 
 GeneralMarketData_LTCUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=1")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/1")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -92,15 +100,17 @@ GeneralMarketData_LTCUSD <- function () {
 #' @keywords Darkcoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_DRKUSD()
+#' }
 
 #DARKCOIN to USD - Realtime
 
 GeneralMarketData_DRKUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=213")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/213")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -111,15 +121,17 @@ GeneralMarketData_DRKUSD <- function () {
 #' @keywords Ripple
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_XRPUSD()
+#' }
 
 #Ripple to US Dollars- Realtime
 
 GeneralMarketData_XRPUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=442")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/442")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
   
@@ -131,15 +143,17 @@ GeneralMarketData_XRPUSD <- function () {
 #' @keywords ReddCoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_RDDUSD()
+#' }
 
 #ReddCoin to US Dollars- Realtime
 
 GeneralMarketData_RDDUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=262")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/262")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
   
@@ -151,15 +165,17 @@ GeneralMarketData_RDDUSD <- function () {
 #' @keywords Peercoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_PCCUSD()
+#' }
 
 #PeerCoin to US Dollars- Realtime
 
 GeneralMarketData_PCCUSD <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=305")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/305")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
   
@@ -171,15 +187,17 @@ GeneralMarketData_PCCUSD <- function () {
 #' @keywords Dogecoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_DOGEBTC()
+#' }
 
 #DOGECOIN to BITCOIN - Realtime
 
 GeneralMarketData_DOGEBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=132")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/132")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -190,15 +208,17 @@ GeneralMarketData_DOGEBTC <- function () {
 #' @keywords Darkcoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_DRKBTC()
+#' }
 
 #DARKCOIN to BITCOIN - Realtime
 
 GeneralMarketData_DRKBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=2")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/2")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -209,15 +229,17 @@ GeneralMarketData_DRKBTC <- function () {
 #' @keywords Feathercoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_FTCBTC()
+#' }
 
 #FEATHERCOIN to BITCOIN - Realtime
 
 GeneralMarketData_FTCBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=5")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/5")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -228,15 +250,17 @@ GeneralMarketData_FTCBTC <- function () {
 #' @keywords Litecoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_LTCBTC()
+#' }
 
 #LITECOIN to BITCOIN - Realtime
 
 GeneralMarketData_LTCBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=3")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/3")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -247,15 +271,17 @@ GeneralMarketData_LTCBTC <- function () {
 #' @keywords NXTcoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_NXTBTC()
+#' }
 
 #NXTCOIN to BITCOIN - Realtime
 
 GeneralMarketData_NXTBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=159")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/159")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -263,18 +289,19 @@ GeneralMarketData_NXTBTC <- function () {
 #' 42coin to Bitcoin
 #'
 #' This function allows you to get general market data on 42coin to BITCOIN
-#' @keywords 42coin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_42CBTC()
+#' }
 
 #42COIN to BITCOIN - Realtime
 
 GeneralMarketData_42CBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=141")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/141")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -285,16 +312,18 @@ GeneralMarketData_42CBTC <- function () {
 #' @keywords Unobtanium
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_UNOBTC()
+#' }
 
 
 #Unobtanium to Bitcoin - Realtime
 
 GeneralMarketData_UNOBTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=133")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/133")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -305,15 +334,17 @@ GeneralMarketData_UNOBTC <- function () {
 #' @keywords Dogecoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_DOGELTC()
+#' }
 
 #DOGECOIN to LITECOIN - Realtime
 
 GeneralMarketData_DOGELTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=135")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/135")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -324,15 +355,17 @@ GeneralMarketData_DOGELTC <- function () {
 #' @keywords AndroidsTokensV2 
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_ADTLTC()
+#' }
 
 #AndroidsTokensV2 to LITECOIN - Realtime
 
 GeneralMarketData_ADTLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=94")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/94")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -343,34 +376,38 @@ GeneralMarketData_ADTLTC <- function () {
 #' @keywords AnonCoin 
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_ANCLTC()
+#' }
 
 #AnonCoin to LITECOIN - Realtime
 
 GeneralMarketData_ANCLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=121")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/121")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
 
-#' AsicCoin   to Litecoin
+#' AsicCoin to Litecoin
 #'
 #' This function allows you to get general market data on AsicCoin to LITECOIN
 #' @keywords AsicCoin  
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_ASCLTC()
+#' }
 
 #AsicCoin  to LITECOIN - Realtime
 
 GeneralMarketData_ASCLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=111")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/111")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -381,15 +418,17 @@ GeneralMarketData_ASCLTC <- function () {
 #' @keywords AuroraCoin   
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_AURLTC()
+#' }
 
 #AuroraCoin  to LITECOIN - Realtime
 
 GeneralMarketData_AURLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=161")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/161")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -400,15 +439,17 @@ GeneralMarketData_AURLTC <- function () {
 #' @keywords BatCoin  
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_BATLTC()
+#' }
 
 #BatCoin to LITECOIN - Realtime
 
 GeneralMarketData_BATLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=186")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/186")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -419,15 +460,17 @@ GeneralMarketData_BATLTC <- function () {
 #' @keywords BlackCoin
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_BATLTC()
+#' }
 
 #BlackCoin  to LITECOIN - Realtime
 
 GeneralMarketData_BCLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=191")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/191")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -439,15 +482,17 @@ GeneralMarketData_BCLTC <- function () {
 #' @keywords CAIx
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_CAIxLTC()
+#' }
 
 #CAIx  to LITECOIN - Realtime
 
 GeneralMarketData_CAIxLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=222")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/222")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
@@ -458,15 +503,17 @@ GeneralMarketData_CAIxLTC <- function () {
 #' @keywords CryptogenicBullion
 #' @export
 #' @examples
+#' \dontrun{
 #' GeneralMarketData_CGBLTC()
+#' }
 
 #CryptogenicBullion  to LITECOIN - Realtime
 
 GeneralMarketData_CGBLTC <- function () {
-  internetcheck <- url.exists("http://pubapi.cryptsy.com", timeout = 10)
+  internetcheck <- url.exists("https://api.cryptsy.com", timeout = 30)
   if( internetcheck != TRUE)
     stop('Cryptsy or your internet connection is down')
-  data <- getURL("http://pubapi.cryptsy.com/api.php?method=singlemarketdata&marketid=123")
+  data <- getURL("https://api.cryptsy.com/api/v2/markets/123")
   dataFrame <- RJSONIO::fromJSON(data)
   return (dataFrame)
 }
